// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#pragma once

namespace base::Platform {

[[nodiscard]] inline QString FileNameFromUserString(QString name) {
	return name;
}

} // namespace base::Platform
